@@ -5,6 +5,10 @@ from configerus.plugin import FormatFactory, SourceFactory
 from .source import ConfigSourcePathPlugin
 from .format import ConfigFormatFilePlugin
 
+
+CONFIGERUS_PATH_KEY = 'path'
+""" if you load paths from config, this is the key that should give the path """
+
 PLUGIN_ID_SOURCE_PATH = 'path'
 """ ConfigSource plugin_id for the configerus path configsource plugin """
 
@@ -15,7 +19,7 @@ def plugin_factory_configsource_path(config: Config, instance_id: str = ''):
     return ConfigSourcePathPlugin(config, instance_id)
 
 
-PLUGIN_ID_FORMAT_FILE = 'file'
+PLUGIN_ID_FORMAT_FILE = 'configerus.plugin.formatter.file'
 """ Format plugin_id for the configerus filepath format plugin """
 
 
